@@ -1,15 +1,12 @@
 package Enbld;
 
-use strict;
+use 5.012;
 use warnings;
 
-use 5.010001;
-
-our $VERSION = '0.7032_1';
-
 use FindBin qw/$Script/;
 use Getopt::Long;
-use Try::Lite;
+
+our $VERSION = '0.7011';
 
 require Exporter;
 our @ISA    = qw(Exporter);
@@ -25,13 +22,14 @@ our @EXPORT = qw/
     annotation
     conf
     load
-    copy
     set
     from
     to
     content
 /;
 
+use Enbld::Catchme;
+
 require Enbld::App::Configuration;
 require Enbld::Logger;
 require Enbld::Target;
@@ -91,7 +89,7 @@ sub enbld($$) {
     }
 
     foreach my $filepath ( sort keys %rcfile_collection ) {
-        do_rcfile( $rcfile_collection{$filepath} );
+        load_or_set_rcfile( $rcfile_collection{$filepath} );
     }
 
     undef $initialized;
@@ -117,25 +115,25 @@ sub build_target {
 
     my $target = Enbld::Target->new( $name, $config );
 
-    my $installed = try {
-        return Enbld::Feature->is_deploy_mode ?
-            $target->deploy_declared( \%target_collection ) :
-            $target->install_declared( \%target_collection );
-    } ( 'Enbld::Error' => sub {
+    my $installed;
+    eval {
+        if ( Enbld::Feature->is_deploy_mode ) {
+            $installed = $target->deploy_declared( \%target_collection );
+        } else {
+            $installed = $target->install_declared( \%target_collection );
+        }
+    };
+
+	catchme 'Enbld::Error' => sub {
         Enbld::Message->alert( $@ );
 
-        if ( $^O ne 'darwin' ) {
-            say "If you run Enbld at Linux or BSD, there is a possibility " .
-            "that the Software which depends is not installed.";
-        }
-
-        say "\n" . "Please check build logile:" . Enbld::Logger->logfile;
+        print "\n";
+        print "Please check build logile:" . Enbld::Logger->logfile . "\n";
 
         $target_result{$name} = $name . ' is failure to build.';
 
         return;
-        }
-      );
+    };
 
     # Target is installed.
     if ( $installed ) {
@@ -293,7 +291,7 @@ sub modules($) {
 
 our $rcfile_condition;
 sub conf($$) {
-    my ( $filepath, $coderef ) = @_;
+    my ( $filepath, $coderef ) = @_;    
 
     if ( ! $initialized ) {
         _err(
@@ -325,22 +323,26 @@ sub conf($$) {
     undef $rcfile_condition;
 }
 
-sub do_rcfile {
+sub load_or_set_rcfile {
     my $rcfile = shift;
 
-    my $result = try {
-        return $rcfile->do;
-    } ( 'Enbld::Error' => sub {
+    my $result;
+    eval {
+        $result = $rcfile->do;
+    };
+
+    # Catch exception.
+	catchme 'Enbld::Error' => sub {
         Enbld::Message->alert( $@ );
 
-        say "\n" . "Please check build logile:" . Enbld::Logger->logfile;
+        print "\n";
+        print "Please check build logile:" . Enbld::Logger->logfile . "\n";
 
         $rcfile_result{$rcfile->filepath} =
-            $rcfile->filepath . ' is failure to create.';
+            $rcfile->filepath . ' is failure to load or set.';
 
         return;
-        }
-      );
+    };
 
     # Configuration file is loaded or set.
     if ( $result ) {
@@ -349,14 +351,14 @@ sub do_rcfile {
         Enbld::App::Configuration->write_file;
 
         $rcfile_result{$rcfile->filepath} =
-            $rcfile->filepath . ' is created.';
+            $rcfile->filepath . ' is loaded or set.';
 
         return $result;
     }
 
     # Configuration file is not loaded or set.
     $rcfile_result{$rcfile->filepath} =
-        $rcfile->filepath . ' is not created.';
+        $rcfile->filepath . ' is not loaded or set.';
 
     return;
 }
@@ -373,20 +375,20 @@ sub set(&) {
     return $_[0];
 }
 
-sub copy(&) {
-    $rcfile_condition->{command} = 'copy';
-
-    return $_[0];
-}
-
 sub from($) {
-    my $from = shift;
+    my $url = shift;
 
-    if ( ref( $from ) ) {
+    if ( ref( $url ) ) {
         _err( "Function 'from' requsres string type parameter." );
     }
 
-    $rcfile_condition->{from} = $from;
+    my $pattern = q{s?https?://[-_.!~*'()a-zA-Z0-9;/?:@&=+$,%#]+};
+
+    if ( $url !~ /$pattern/ ) {
+        _err( "Function 'from' requires valid URL parameter.", $url );
+    }
+
+    $rcfile_condition->{url} = $url;
 }
 
 sub to($) {
@@ -396,11 +398,11 @@ sub to($) {
         _err( "Function 'to' requsres string type parameter." );
     }
 
-    if ( $to =~ /\s/ ) {
+    if ( $rcfile_condition->{directory} =~ /\s/ ) {
         _err( "Function 'to' must not contain space character." );
     }
 
-    $rcfile_condition->{directory} = $to;
+    $rcfile_condition->{directory} = shift;
 }
 
 sub content($) {
@@ -455,14 +457,14 @@ sub parse_option {
 
     if ( Enbld::Feature->is_make_test_all ) {
         Enbld::Message->notify(
-                "INFO:Enbld is set 'make test mode'.\n" .
+                "INFO:Enbld::Declare is set 'make test mode'.\n" .
                 "All targets will be tested."
                 );
     }
 
     if ( Enbld::Feature->is_force_install ) {
         Enbld::Message->notify(
-                "INFO:Enbld is set 'force install mode'.\n" .
+                "INFO:Enbld::Declare is set 'force install mode'.\n" .
                 "All targets will be builded by force."
                 );
     }
@@ -477,233 +479,223 @@ sub _err {
 
 1;
 
-__END__
-
 =pod
 
 =head1 NAME
 
-Enbld - Yet another package manager for building development environment
+Enbld - Build your development environment by perl-based DSL.
 
 =head1 SYNOPSIS
 
-=head2 Installation
-
-  $ curl -L http://goo.gl/MrbDDB | perl
-
-=head2 Prepare a conditions script
-
-  $ cat conditions_for_build.pl
-  #!/usr/bin/perl
-
-  use strict;
-  use warnings;
-
-  use lib "$ENV{HOME}/.enbld/extlib/lib/perl5/";
-
-  use Enbld;
-
-  enbld 'mydevenv' => build {
-
-      # install latest version
-      target 'git' => define {
-          version 'latest';
-      };
-
-      # install specific version
-      target 'perl' => define {
-          version '5.18.1';
-      };
-
-  };
-
-=head2 Run as perl script
-
-  $ chmod +x conditions_for_build.pl
-  $ ./conf_for_build.pl
-
-  -> Installs software according to the conditions which are defined at script.
-
-=head1 DESCRIPTION
-
-B<Enbld is yet another package manager for building development environment.>
-
-Write conditions of software installation (a version - latest or specific version , the execution of a test code etc.) to a conditions script, and run as perl script.
-
-Then Enbld installs software according to the conditions which is defined in script.
-
-=head2 FEATURES
-
-=over
-
-=item 1. The conditions of installation are defined by perl-based DSL
-
-Once it writes a conditions script, the same environment will become reproducible easily.
-
-=item 2. The specified versions can install
-
-Unlike other package management systems, Enbld does not fix a version.
-
-The version to install can be specified freely.
-
-And version 'latest' also can be specified. In this case the latest version is decided automatically, and it be installed.
-
-=item 3. The release of the newer version can check
-
-The software specified version 'latest' can check release of the newer version.
-
-So the software upgraded frequently (vim, git, etc.) can always use the latest version.
-
-=item 4. The all software are installed in a home directory.
-
-There is not require sudo for installation.
-
-Backup and remove is easy.
-
-=item 5. The same interface of installation is offered for all programing languages
-
-Unlike other programing language version manager, the same interface of installatin is offered for all programing languages.
-
-You do not need to learn a different way for every programming language.
-
-=back
-
-=head2 ANTI FEATURES
-
-=over
-
-=item 1. Enbld does NOT aim at perfect package manager
-
-The selection plan of the software to support by Enbld is as follows.
-
-=over
-
-=item * The software for development updated frequently
-
-e.g. vim, git
-
-=item * The Software which has a specific version specified by the projects.
-
-e.g.
-
-programming language (perl, ruby, nodejs, scala etc.)
-
-Web Server (apache, nginx etc.)
-
-Database (MySQL etc.)
-
-=item * The software required for a developer although not installed in OS X
-
-e.g. tmux
-
-=back
-
-The software which does not correspond to the above-mentioned base does not support.
-
-=item 2. Enbld does not offer the features which overlaps with the module install features in which a programming language offers.
-
-CPAN, Rubygem, etc. should use for a module install features which a programming language offers.
-
-=back
-
-=head2 CAUTION
-
-B<Enbld does not gurantee success of building of all the versions.>
-
-Since log file is displayed when building goes wrong, please analyze and send report:)
-
-=head1 INSTALLATION
-
-=head2 SUPPORTED PLATFORMS
-
-B<Enbld is performing verification of running on OS X Mavericks.>
-
-Probably, it may operate also on Linux (Debian, Ubuntu etc.). When not running, it is waiting for the report :)
-
-=head2 REQUIREMENTS
-
-=over
-
-=item * perl 5.10.1 or above
-
-Enbld certainly use the system perl (`/usr/bin/perl`).
-
-=item * GNU Make
-
-=item * compiler (gcc or clang)
-
-=item * other stuff required for individual target software (e.g. JRE for scala)
-
-=back
-
-=head2 INSTALL
-
- $ curl -L http://goo.gl/MrbDDB | perl
-
-Enbld installs all the components in a C<$HOME/.enbld> directory. Therefore, it is necessary to set the PATH of the software which Enbld installed. 
-
-=head2 SET PATH
-
-In C<.bashrc> or C<.bash_profile>, add below setting.
-
- export PATH=$HOME/.enbld/bin:$HOME/.enbld/extlib/bin:$PATH
- export MANPATH=$HOME/.enbld/share/man:$HOME/.enbld/man:$MANPATH
-
-=head1 GETTING STARTED Enbld
-
-=head2 INSTALL LATEST VERSION
-
-=head3 Ready conditions script
-
- $ cat samples/git_install.pl
  #!/usr/bin/perl
 
- use strict;
+ use 5.012;
  use warnings;
 
+ use utf8;
+
  use lib "$ENV{HOME}/.enbld/extlib/lib/perl5/";
 
  use Enbld;
 
- enbld 'mydevenv' => build {
+ enbld 'myenv' => build {
+
+     # install latest version
+     target 'git' => define {
+         version 'latest';
+     };
+
+     # install specific version
+     target 'tmux' => define {
+         version '1.8';
+     };
+
+     # install software and set configuration file
+     target 'vim' => define {
+         version 'latest';
+     };
+
+     conf '.vimrc' => load {
+         from 'https://raw.github.com/magnolia-k/vimrc/master/.vimrc';
+     };
+ };
+
+=head1 DESCRIPTION
+
+B<Enbld is a tool for building development environment.>
+
+Write installation conditions (a version - latest or specific version number, the execution of a test code, configuration file etc.) of target software in perl-based DSL,then download of a source code, building, and installation will be performed altogether automatically.
+
+If DSL is performed once again when the software of a later more high version is released, the latest version will be installed automatically.
+
+
+=head2 FEATURES
+
+=over 3
+
+=item * Configuration file which described installation conditions is defined by perl-based DSL. 
+
+Once it writes a configuration file, same environment is easily reproducible . 
+
+=item * Arbitrary versions are installable. 
+
+If it is specified as 'latest', the latest version will be judged automatically and it will be installed. 
+
+=item * The version will be installed if arbitrary versions are specified. 
+
+Like other package management systems (Homebrew, MacPorts etc.), the package managerial system side does not specify a version. 
+
+=item * It can be confirmed whether a version higher than the version installed is released. 
+
+The software (vim, git, etc.) upgraded frequently can also always use the latest version. 
+
+=item * All software is installed in a home directory.
+
+Software which became unnecessary can be deleted easily. 
+
+=back
+
+=head3 Supported software
+
+Now, Enbld supports for installation below software.
+
+ apache         http://httpd.apache.org
+ apr            http://apr.apache.org
+ aprutil        http://apr.apache.org
+ autoconf       http://www.gnu.org/software/autoconf/
+ automake       http://www.gnu.org/software/automake/
+ cmake          http://www.cmake.org
+ emacs          http://www.gnu.org/software/emacs/
+ git            http://git-scm.com
+ groff          http://www.gnu.org/software/groff/
+ hello          http://www.gnu.org/software/hello/
+ libevent       http://libevent.org
+ libidn         http://www.gnu.org/software/libidn/
+ libtool        http://www.gnu.org/software/libtool/
+ mysql          http://www.mysql.com
+ nginx          http://nginx.org
+ nodejs         http://nodejs.org
+ pcre           http://www.pcre.org
+ perl           http://www.perl.org
+ pkgconfig      http://www.freedesktop.org/wiki/Software/pkg-config/
+ python         http://www.python.org
+ rakudostar     http://rakudo.org
+ ruby           https://www.ruby-lang.org
+ scala          http://www.cmake.org
+ tmux           http://tmux.sourceforge.net
+ tree           http://mama.indstate.edu/users/ice/tree/
+ vim            http://www.vim.org
+ wget           http://www.gnu.org/software/wget/
+ zsh            http://www.zsh.org
+
+
+=head2 ANTI-FEATURES
+
+=over 3
+
+=item * Enbld does NOT aim at perfect package management software. 
+
+The selection plan of the software to support by Enbld is as follows. 
+
+=over 3
+
+=item * Software required for a developer updated frequently (e.g. git, vim).
+
+=item * Software with which the developer who has participated in the project needs to unite a version (e.g. web server, database, programming language etc.).
+
+=item * Software required for a developer although not installed in Mac OS X (e.g. tmux).
+
+=back
+
+=item * It does not have a function which overlaps with the module controlling function which each software has (e.g. CPAN,gem etc.).
+
+=back
+
+=head2 SUPPORTED PLATFORMS
+
+B<Enbld is performing verification of running on Mac OS X 10.8 Mountain Lion.>
+
+Probably, it may operate also on Linux (Debian etc.). 
+When not running, it is waiting for the report :)
+
+=head2 CAUTION
+
+B<Success of building of all the versions is not guaranteed. Since log file is displayed when building goes wrong, please analyze and send report:)>
+
+
+=head2 INSTALLATION
+
+ $ git clone https://github.com/magnolia-k/Enbld.git
+ $ cd Enbld
+ $ ./setup
+
+And set Enbld's path.
+
+In .bashrc, write below setting.
+
+ export $PATH=$HOME/.enbld/bin:$HOME/.enbld/extlib/bin:$PATH
+ export MANPATH=$HOME/.enbld/share/man:$HOME/.enbld/man:$MANPATH
+
+=head1 GETTING STARTED
+
+=head2 INSTALL LATEST VERSION
+
+=head3 Ready configuration file
+
+ $ cat samples/git_install.plx
+ #!/usr/bin/perl
+
+ use 5.012;
+ use warnings;
+
+ use utf8;
+
+ use lib "$ENV{HOME}/.enbld/extlib/lib/perl5/";
+
+ use Enbld;
+
+ enbld 'myenv' => build {
 
      target 'git' => define {
          version 'latest';
      };
  }
 
-=head3 Run as perl script
+=head3 Execute configuration file
 
- $ ./samples/git_install.pl
+ $ ./samples/git_install.plx
 
-=head3 Finish installation
+=head3 Target software is installed
 
  $ git --version
  git version [latest version]
 
-=head3 Upgrade
+=head3 Upgrade installed software
 
-Then, if the newer version is released, please run script again.
+Then, if the software of a latest version is released, please execute a configuration file again. 
+The software of the latest version will be installed.
 
- $ ./samples/git_install.pl
+ $ ./samples/git_install.plx
 
-The latest version will be installed.
+Latest software is installed.
 
 =head2 INSTALL SPECIFIC VERSION
 
-A specific version is specified in a conditions script. -> version '5.18.1';
+A specific version is specified in setting file. -> version '5.18.1';
 
- $ cat samples/specific_version_install.pl
+ $ cat samples/specific_version_install.plx
  #!/usr/bin/perl
     
- use strict;
+ use 5.012;
  use warnings;
     
+ use utf8;
+    
  use lib "$ENV{HOME}/.enbld/extlib/lib/perl5/";
     
  use Enbld;
     
- enbld 'mydevenv' => build {
+ enbld 'myenv' => build {
     
      target 'perl' => define {
          version '5.18.1';
@@ -715,80 +707,109 @@ A specific version is specified in a conditions script. -> version '5.18.1';
 
  $ perl -v
 
- This is perl 5, version 18, subversion 1 (v5.18.1) built for ...
+ This is perl 5, version 18, subversion 1 (v5.18.1) built for darwin-multi-2level
+
+=head2 DOWNLOAD OR CREATE SOFTWARE' CONFIGURATION FILE (DOTFILE)
+
+Enbld also can create software' configuration file(.dotfile).
+
+'conf' function set software' configuration file to home directory.
+
+=head3 Download software' configuration file
+
+ $ cat samples/vim_install.plx
+ #!/usr/bin/perl
+    
+ use 5.012;
+ use warnings;
+    
+ use utf8;
+    
+ use lib "$ENV{HOME}/.enbld/extlib/lib/perl5/";
+    
+ use Enbld;
+    
+ enbld 'myenv' => build {
+    
+     target 'vim' => define {
+         version 'latest';
+     };
+    
+     conf '.vimrc' => load {
+         from 'https://raw.github.com/magnolia-k/vimrc/master/.vimrc';
+     };
+    
+ };
+
+'.vimrc' is downloaded to $HOME from 'https://raw.github.com/magnolia-k/vimrc/master/.vimrc'.
+
+Nothing is done when the file of the same file name already exists. 
+
+
+=head3 Create software' configuration file
+
+ conf '.vimrc' => set {
+     content 'syntax on';
+     content 'set cindent';
+ };
+
+'.vimrc' is created to $HOME.
+
+Nothing is done when the file of the same file name already exists. 
+
+
+=head2 MAKE TEST AT INSTALLATION
+
+Enbld can make test at installation.
+
+ target 'git' => define {
+     version 'latest';
+     make_test 1;
+ };
+
+As default, this function is OFF. 
+
+If a test goes wrong, also building will go wrong. 
+
 
 =head2 ADD ARGUMENTS
 
-'arguments' method adds an additional arguments to 'configure' script.
+'arguments' method adds additional arguments to './configure'.
 
  target 'perl' => define {
      version '5.18.1';
      arguments '-Dusethreads';
  };
 
-perl 5.18.1 with thread is builded.
+perl 5.18.1 with thread
 
  $ perl -v
     
  This is perl 5, version 18, subversion 1 (v5.18.1) built for darwin-thread-multi-2level
 
-=head2 INSTALL SOFTWARE WHICH DEPENDS 
-
-When using Enbld at OS X, Enbld also solve the dependencies between softwares automatically.
-
-For example, when the is equal to which needs a libidn library for wget, and Enbld install wget, they also install libidn automatically.
-
-  $ enblder install wget
-  =====> Start building target 'wget'.
-  =====> Found dependencies.
-  --> Dependency 'libidn'.
-  --> libidn is not installed yet.
-  =====> Start building target 'libidn'.
-
-Please solve the software which needs the fix patterns of a dependencies at that of a many using the package Management manager of operating system in operating system of Linux and BSD(s) other than OS X.
-
 =head2 UTILITY COMMAND 'enblder'
 
 Enbld installs utility command 'enblder'.
 
-The main commands are shown below. 
-
-The description of all commands are shown by C<perldoc enblder>.
-
 =head3 Displays available software
 
-Subcommand 'available' displays software list that can install by Enbld.
+Subcommand 'available' displays software that can install by Enbld.
 
  $ enblder available
 
-The name displayed on this list is used for the name of the Software which I specify as a condition script. 
-
-=head3 Install the software
-
-subcommand 'install' installs the latest version of the software.
-
-Use to install Software, without writing a condition script.
-
-Then the 'freeze' subcommand is used, displays the conditions script reflecting the installation.
 
 =head3 Displays installed software
 
-Subcommand 'list' displays software list that is installed.
+Subcommand 'list' displays software that is installed.
 
  $ enblder list
 
-=head3 Displays conditions script
+=head3 Displays configuration file
 
-Subcommand 'freeze' displays the condition script reproducing the software of an installed. 
+Subcommand 'freeze' displays configuration file that is condition of installed software.
 
  $ enblder freeze
 
-If the displayed content is redirected to a text file, it will become a script of perl which can be performed as it is. 
-
- $ enblder freeze > conditions.pl
- $ chmod +x conditions.pl
- $ ./conditions.pl
-
 =head3 Displays outdated software
 
 Subcommand 'outdated' displays outdated software list.
@@ -801,70 +822,11 @@ Subcommand 'upgrade' upgrade outdated software.
 
  $ enblder upgrade git
 
-=head1 HOW TO USE RECOMMENDATION OF Enbld
-
-I introduce how to use recommendation of Enbld for the the last. 
-
-=over
-
-=item 1 Install Enbld
-
-  $ curl -L http://goo.gl/MrbDDB | perl
-
-=item 2 Display available software list
-
-  $ enblder available
-
-=item 3 Install software to always use the latest version.
-
-  $ enblder install git
-
-=item 4 Make conditions script
-
-  $ enblder freeze > my_conditions.pl
-  $ chmod +x my_conditions.pl
-
-=item 5 Add a software to use a specific version
-
-  target 'perl' => define {
-      version '5.18.1';
-  }
-
-=item 6 Run a conditions script
-
-  $ ./conditions.pl
-
-=item 7 Sometimes check the release of the newer version
-
-  $ enblder outdated
-
-=item 8 Upgrade outdated software  
- 
-  $ enblder upgrade git
-
-=item 9 Since a trouble is surely encountered by somewhere, please send me a report or a Patch :)
-
-L<https://github.com/magnolia-k/Enbld/issues>
-
-=item 10 Repeat 7 -> 10
-
-=back
-
 =head1 SEE ALSO
 
-L<Enbld::Tutorial>
+L<lib/Enbld::Tutorial>
 
-L<enblder>
-
-=head1 WEB SITE
-
-L<https://github.com/magnolia-k/Enbld>
-
-L<http://code-stylistics.net/enbld>
-
-=head1 ISSUE REPORT
-
-L<https://github.com/magnolia-k/Enbld/issues>
+L<bin/enblder>
 
 =head1 COPYRIGHT
 
